Package: LBE
Type: Package
Title: Estimation of the false discovery rate
Version: 1.80.0
Date: 2024-05-08
Author: Cyril Dalmasso
Maintainer: Cyril Dalmasso <cyril.dalmasso@univ-evry.fr>
Description: LBE is an efficient procedure for estimating the
        proportion of true null hypotheses, the false discovery rate
        (and so the q-values) in the framework of estimating procedures
        based on the marginal distribution of the p-values without
        assumption for the alternative hypothesis.
Depends: stats
Imports: graphics, stats, utils
License: GPL-2
Suggests: qvalue
biocViews: MultipleComparison
git_url: https://git.bioconductor.org/packages/LBE
git_branch: RELEASE_3_23
git_last_commit: 486aee3
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:52:50 UTC; biocbuild
